summaryrefslogtreecommitdiffstats
path: root/src/gui/general/BaseTool.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/general/BaseTool.h')
-rw-r--r--src/gui/general/BaseTool.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/gui/general/BaseTool.h b/src/gui/general/BaseTool.h
index 6dd6820..29ef8dd 100644
--- a/src/gui/general/BaseTool.h
+++ b/src/gui/general/BaseTool.h
@@ -44,9 +44,10 @@ namespace Rosegarden
* handling by a BaseToolBox
*
*/
-class BaseTool : public QObject
+class BaseTool : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
friend class BaseToolBox;
@@ -55,14 +56,14 @@ public:
virtual ~BaseTool();
/**
* Is called by the parent View (EditView or SegmentCanvas) when
* the tool is set as current.
- * Add any setup here (e.g. setting the mouse cursor shape)
+ * Add any setup here (e.g. setting the mouse cursor tqshape)
*/
virtual void ready();
/**
* Is called by the parent View (EditView or SegmentCanvas) after
* the tool is put away.
* Add any cleanup here
*/
@@ -87,7 +88,7 @@ protected:
*
* \a menuName : the name of the menu defined in the XML rc file
*/
- BaseTool(const TQString& menuName, KXMLGUIFactory*, TQObject* parent);
+ BaseTool(const TQString& menuName, KXMLGUIFactory*, TQObject* tqparent);
virtual void createMenu() = 0;
virtual bool hasMenu() { return false; }
@@ -100,7 +101,7 @@ protected:
TQString m_menuName;
TQPopupMenu* m_menu;
- KXMLGUIFactory* m_parentFactory;
+ KXMLGUIFactory* m_tqparentFactory;
TQString m_contextHelp;
};
@@ -55,14 +56,14 @@ public:
virtual ~BaseTool();
/**
- * Is called by the parent View (EditView or SegmentCanvas) when
+ * Is called by the tqparent View (EditView or SegmentCanvas) when
* the tool is set as current.
@@ -55,14 +56,14 @@ public:
virtual void ready();
/**
- * Is called by the parent View (EditView or SegmentCanvas) after
+ * Is called by the tqparent View (EditView or SegmentCanvas) after
* the tool is put away.
* Add any cleanup here